==> alpyca-2.0.1rc1-py3-none-any.whl: alpaca/safetymonitor.py <==
# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# safetymonitor - Implements ASCOM Alpaca SafetyMonitor device class
#
# Part of the Alpyca application interface package
#
# Author:   Robert B. Denny <rdenny@dc3.com> (rbd)
#
# Python Compatibility: Requires Python 3.7 or later
# Doc Environment: Sphinx v4.5.0 with autodoc, autosummary, napoleon, and autoenum
# GitHub: https://github.com/BobDenny/alpyca-client
#
# -----------------------------------------------------------------------------
# MIT License
#
# Copyright (c) 2022 Ethan Chappel and Bob Denny
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# -----------------------------------------------------------------------------
# Edit History:
# 02-May-22 (rbd) Initial Edit
# 13-May-22 (rbd) 2.0.0-dev1 Project now called "Alpyca" - no logic changes
# -----------------------------------------------------------------------------
from alpaca.device import Device

class SafetyMonitor(Device):
    """ASCOM Standard ISafetyMonitor V1 Interface.
    
    Provides a single property that indicates whether it is safe to expose
    the observatory instruments to the outside environment, or not. The
    measurements of meterological conditions that your application (or a 
    separate weather monitoring system) uses to make this decision will
    most often come from sensors that are accessed through the 
    :py:class:`~alpaca.observingconditions.ObservingConditions` interface.
    
    """

    def __init__(
        self,
        address: str,
        device_number: int,
        protocol: str = "http"
    ):
        """Initialize the SafetyMonitor object.
              
        Args:
            address (str): IP address and port of the device (x.x.x.x:pppp)
            device_number (int): The index of the device (usually 0)
            protocol (str, optional): Only if device needs https. Defaults to "http".

        """
        super().__init__(address, "safetymonitor", device_number, protocol)

    @property
    def IsSafe(self) -> bool:
        """The monitored state is safe for use.

        Raises:
            NotConnectedException: If the device is not connected
            DriverException: An error occurred that is not described by
                one of the more specific ASCOM exceptions.
                The device did not *successfully* complete the request.
        
        """
        return self._get("issafe")

==> alpyca-3.1.0-py3-none-any.whl: alpaca/safetymonitor.py <==
# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# safetymonitor - Implements ASCOM Alpaca SafetyMonitor device class
#
# Part of the Alpyca application interface package
#
# Author:   Robert B. Denny <rdenny@dc3.com> (rbd)
#
# Python Compatibility: Requires Python 3.9 or later
# Doc Environment: Sphinx v5.0.2 with autodoc, autosummary, napoleon, and autoenum
# GitHub: https://github.com/ASCOMInitiative/alpyca
#
# -----------------------------------------------------------------------------
# MIT License
#
# Copyright (c) 2022-2024 Ethan Chappel and Bob Denny
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# -----------------------------------------------------------------------------
# Edit History:
# 02-May-22 (rbd) Initial Edit
# 13-May-22 (rbd) 2.0.0-dev1 Project now called "Alpyca" - no logic changes
# 08-Mar-24 (rbd) 3.0.0 Add Master Interfaces refs to all members
# 22-Nov-24 (rbd) 3.0.1 For PDF rendering no change to logic
# -----------------------------------------------------------------------------
from alpaca.device import Device

class SafetyMonitor(Device):
    """ASCOM Standard ISafetyMonitor V1 Interface.

    Provides a single property that indicates whether it is safe to expose
    the observatory instruments to the outside environment, or not. The
    measurements of meterological conditions that your application (or a
    separate weather monitoring system) uses to make this decision will
    most often come from sensors that are accessed through the
    :py:class:`~alpaca.observingconditions.ObservingConditions` interface.

    """

    def __init__(
        self,
        address: str,
        device_number: int,
        protocol: str = "http"
    ):
        """Initialize the SafetyMonitor object.

        Args:
            address (str): IP address and port of the device (x.x.x.x:pppp)
            device_number (int): The index of the device (usually 0)
            protocol (str, optional): Only if device needs https. Defaults to "http".

        """
        super().__init__(address, "safetymonitor", device_number, protocol)

    @property
    def IsSafe(self) -> bool:
        """The monitored state is safe for use.

        Raises:
            NotConnectedException: If the device is not connected
            DriverException: An error occurred that is not described by one of the more specific ASCOM exceptions. The device did not *successfully* complete the request.

        .. admonition:: Master Interfaces Reference
            :class: green

            .. only:: html

                |IsSafe|

                .. |IsSafe| raw:: html

                    <a href="https://ascom-standards.org/newdocs/safetymonitor.html#SafetyMonitor.IsSafe" target="_blank">
                    SafetyMonitor.IsSafe</a> (external)

            .. only:: rinoh

                `SafetyMonitor.IsSafe <https://ascom-standards.org/newdocs/safetymonitor.html#SafetyMonitor.IsSafe>`_
        """
        return self._get("issafe")
